==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_ja_JP.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja_JP" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>デバイスがビジー状態です</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>デバイス</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>ユーザー</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>最後に録画したビデオをメール</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>複数のビデオを選択してメール</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>送る</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>ビデオプレーヤーをインストールしてください</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>添付ファイルとしてビデオを送ります</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>一つ以上のファイルを選択</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>ウィンドウ枠</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>全画面上に表示</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>右クリックでメニューを表示</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>ユーザー定義</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>デバイスがビジー状態です</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>デバイス</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>ユーザー</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation>ダブルクリックで端まで広げます</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>全画面</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>ウィンドウ</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>範囲</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>拡大</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>オーディオ</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>規定</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>コーデック</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>マウスカーソルを録画しない</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>ビデオ保存パス</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>プレーヤー</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>録画開始時にVokoscreenを最小化</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>送る</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>録画時間</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>サイズ(キロバイト)</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>録画スクリーンサイズ</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>形式</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>フレームレート</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>ディレクトリを開く</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>カウントダウン</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>録画したビデオを再生</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>ビデオをメール送信</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>一つ以上のデバイスを選択</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>実フレームレート</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>再開</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>ホームページ</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>サポート</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>開発者</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>フレーム</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>寄付</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>ソースコード</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>システムトレイに表示</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>新しいバージョンが使用可能です</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>動画コーデック</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音声コーデック</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webカメラ</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Webカメラを選択</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>反転</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>ディスプレイ</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>すべてのディスプレイ</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>開発者ホームページ</translation>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_ja_JP.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja_JP" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>デバイスがビジー状態です</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>デバイス</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>ユーザー</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>最後に録画したビデオをメール</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>複数のビデオを選択してメール</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>送る</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>ビデオプレーヤーをインストールしてください</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>添付ファイルとしてビデオを送ります</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>一つ以上のファイルを選択</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>ウィンドウ枠</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>全画面上に表示</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>右クリックでメニューを表示</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>ユーザー定義</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>デバイスがビジー状態です</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>デバイス</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>ユーザー</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>全画面</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>ウィンドウ</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>範囲</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>拡大</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>オーディオ</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>規定</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>コーデック</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>マウスカーソルを録画しない</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>ビデオ保存パス</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>プレーヤー</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>録画開始時にVokoscreenを最小化</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>送る</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>録画時間</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>サイズ(キロバイト)</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>録画スクリーンサイズ</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>形式</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>フレームレート</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>ディレクトリを開く</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>カウントダウン</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>録画したビデオを再生</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>ビデオをメール送信</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>一つ以上のデバイスを選択</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>実フレームレート</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>再開</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>ホームページ</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>サポート</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>開発者</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>フレーム</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>寄付</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>ソースコード</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>システムトレイに表示</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>新しいバージョンが使用可能です</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>動画コーデック</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音声コーデック</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webカメラ</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Webカメラを選択</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>反転</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>ディスプレイ</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>すべてのディスプレイ</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>開発者ホームページ</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>録画プログラム</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>録画プログラムを選択</translation>
    </message>
    <message>
        <source>Hide window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lossless</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
